@@ -1,13 +1,13 @@
 /*
  * SPDX-FileCopyrightText: 2014 Andreas Xavier <andxav at zoho dot com>
  * SPDX-License-Identifier: GPL-2.0-or-later
-*/
+ */
 
 #include "keduvocdocument.h"
-#include "readermanager.h"
 #include "keduvockvtml2reader.h"
 #include "kvtml2defs.h"
 #include "readerTestHelpers.h"
+#include "readermanager.h"
 
 #include <QDebug>
 #include <QTest>
@@ -64,8 +64,7 @@ private slots:
     void testParseImageUrl();
     void testParseImageUrl_data();
 
-private :
-
+private:
 };
 
 /**
@@ -78,24 +77,24 @@ public:
     XMLGenerator();
     ~XMLGenerator();
 
-    //String Data
+    // String Data
     const QString generator, author, license, comment, date, category, title;
     const QString lang0name, lang0loc, lang1name, lang1loc;
 
-    //Generators of parts of the XML Doc
-    XMLGenerator & preamble();
-    XMLGenerator & minimalInfo();
-    XMLGenerator & missingTitle();
-    XMLGenerator & minimalIds();
-    XMLGenerator & missingLocale();
-    XMLGenerator & minimalEntries();
-    XMLGenerator & minimalHeader();
+    // Generators of parts of the XML Doc
+    XMLGenerator &preamble();
+    XMLGenerator &minimalInfo();
+    XMLGenerator &missingTitle();
+    XMLGenerator &minimalIds();
+    XMLGenerator &missingLocale();
+    XMLGenerator &minimalEntries();
+    XMLGenerator &minimalHeader();
 
-    XMLGenerator & blankInfo();
-    XMLGenerator & addTitle();
+    XMLGenerator &blankInfo();
+    XMLGenerator &addTitle();
 
-    XMLGenerator & blankIdentifier(const int ii);
-    XMLGenerator & addLocale(const int ii);
+    XMLGenerator &blankIdentifier(const int ii);
+    XMLGenerator &addLocale(const int ii);
     XMLGenerator &blankEntry(int entryId);
     XMLGenerator &blankTranslation(int translationId);
     XMLGenerator &addSoundUrl(const QString &soundUrl);
@@ -105,103 +104,111 @@ public:
     XMLGenerator &addContainerEntry(int entryId);
 
     /** Convert to the QIODevice that the reader expects*/
-    QIODevice * toQIODevice();
+    QIODevice *toQIODevice();
     QByteArray m_barray;
-    QBuffer * m_buffer;
+    QBuffer *m_buffer;
 
     KEduVocDocument::FileType myType;
-
 };
 
 XMLGenerator::XMLGenerator()
     : QDomDocument()
-    , generator( QStringLiteral("Parse KVTML2 Unit Tests"))
-    , author( QStringLiteral("Parse KVTML2 Test Author") )
-    , license( QStringLiteral("test license") )
-    , comment( QStringLiteral("comment") )
-    , date( QStringLiteral("2014-01-01") )
-    , category( QStringLiteral("test document") )
-    , title( QStringLiteral("Parse KVTML2 Test Title") )
+    , generator(QStringLiteral("Parse KVTML2 Unit Tests"))
+    , author(QStringLiteral("Parse KVTML2 Test Author"))
+    , license(QStringLiteral("test license"))
+    , comment(QStringLiteral("comment"))
+    , date(QStringLiteral("2014-01-01"))
+    , category(QStringLiteral("test document"))
+    , title(QStringLiteral("Parse KVTML2 Test Title"))
 
-    , lang0name( QStringLiteral("English") )
-    , lang0loc( QStringLiteral("en") )
-    , lang1name( QStringLiteral("German") )
-    , lang1loc( QStringLiteral("de") )
-    , m_buffer( nullptr )
-    , myType( KEduVocDocument::Kvtml )
+    , lang0name(QStringLiteral("English"))
+    , lang0loc(QStringLiteral("en"))
+    , lang1name(QStringLiteral("German"))
+    , lang1loc(QStringLiteral("de"))
+    , m_buffer(nullptr)
+    , myType(KEduVocDocument::Kvtml)
 
 {
 }
-XMLGenerator::~XMLGenerator() {
-    if ( m_buffer ) {
+XMLGenerator::~XMLGenerator()
+{
+    if (m_buffer) {
         delete m_buffer;
     }
 }
 
-QIODevice * XMLGenerator::toQIODevice()
+QIODevice *XMLGenerator::toQIODevice()
 {
     m_barray = this->toString(4).toLatin1();
-    m_buffer = new QBuffer( & m_barray );
-    m_buffer->open( QIODevice::ReadOnly );
+    m_buffer = new QBuffer(&m_barray);
+    m_buffer->open(QIODevice::ReadOnly);
     return m_buffer;
 }
 
-XMLGenerator & XMLGenerator::preamble() {
-    this -> setContent( QStringLiteral( "<!DOCTYPE kvtml PUBLIC \"kvtml2.dtd\" \"http://edu.kde.org/kvtml/kvtml2.dtd\">\n" ) , true, nullptr, nullptr, nullptr);
-    this->appendChild( this->createProcessingInstruction( QStringLiteral("xml"), QStringLiteral("version=\"1.0\" encoding=\"UTF-8\"") ) );
+XMLGenerator &XMLGenerator::preamble()
+{
+    this->setContent(QStringLiteral("<!DOCTYPE kvtml PUBLIC \"kvtml2.dtd\" \"http://edu.kde.org/kvtml/kvtml2.dtd\">\n"), true, nullptr, nullptr, nullptr);
+    this->appendChild(this->createProcessingInstruction(QStringLiteral("xml"), QStringLiteral("version=\"1.0\" encoding=\"UTF-8\"")));
 
-    QDomElement domElementKvtml = this->createElement( KVTML_TAG );
-    this->appendChild( domElementKvtml );
-    domElementKvtml.setAttribute( KVTML_VERSION, ( QString ) QStringLiteral("2.0") );
+    QDomElement domElementKvtml = this->createElement(KVTML_TAG);
+    this->appendChild(domElementKvtml);
+    domElementKvtml.setAttribute(KVTML_VERSION, (QString)QStringLiteral("2.0"));
 
     return *this;
 }
 
-XMLGenerator & XMLGenerator::blankInfo() {
-    QDomElement info = this->createElement( KVTML_INFORMATION );
-    elementsByTagName(KVTML_TAG).at( 0 ).appendChild( info );
+XMLGenerator &XMLGenerator::blankInfo()
+{
+    QDomElement info = this->createElement(KVTML_INFORMATION);
+    elementsByTagName(KVTML_TAG).at(0).appendChild(info);
     return *this;
 }
-XMLGenerator & XMLGenerator::addTitle() {
-    QDomElement mtitle = this->createElement( KVTML_TITLE );
-    QDomText mtitletext = this->createTextNode( title );
-    mtitle.appendChild( mtitletext );
-    elementsByTagName(KVTML_INFORMATION).at( 0 ).appendChild( mtitle );
+XMLGenerator &XMLGenerator::addTitle()
+{
+    QDomElement mtitle = this->createElement(KVTML_TITLE);
+    QDomText mtitletext = this->createTextNode(title);
+    mtitle.appendChild(mtitletext);
+    elementsByTagName(KVTML_INFORMATION).at(0).appendChild(mtitle);
     return *this;
 }
-XMLGenerator & XMLGenerator::minimalInfo() {
+XMLGenerator &XMLGenerator::minimalInfo()
+{
     return blankInfo().addTitle();
 }
 
-XMLGenerator & XMLGenerator::minimalIds() {
-    QDomElement elem = this->createElement( KVTML_IDENTIFIERS ) ;
-    elementsByTagName(KVTML_TAG).at( 0 ).appendChild( elem );
+XMLGenerator &XMLGenerator::minimalIds()
+{
+    QDomElement elem = this->createElement(KVTML_IDENTIFIERS);
+    elementsByTagName(KVTML_TAG).at(0).appendChild(elem);
     return *this;
 }
 
-XMLGenerator & XMLGenerator::minimalEntries() {
-    QDomElement elem = this->createElement( KVTML_ENTRIES ) ;
-    elementsByTagName(KVTML_TAG).at( 0 ).appendChild( elem );
+XMLGenerator &XMLGenerator::minimalEntries()
+{
+    QDomElement elem = this->createElement(KVTML_ENTRIES);
+    elementsByTagName(KVTML_TAG).at(0).appendChild(elem);
     return *this;
 }
 
-XMLGenerator & XMLGenerator::minimalHeader() {
+XMLGenerator &XMLGenerator::minimalHeader()
+{
     return preamble().minimalInfo().minimalIds().minimalEntries();
 }
 
-
-XMLGenerator & XMLGenerator::blankIdentifier(const int ii) {
-    QDomElement id = this->createElement( KVTML_IDENTIFIER );
+XMLGenerator &XMLGenerator::blankIdentifier(const int ii)
+{
+    QDomElement id = this->createElement(KVTML_IDENTIFIER);
     QString str;
-    id.setAttribute(QStringLiteral("id"), str.setNum( ii ) );
-    elementsByTagName(KVTML_IDENTIFIERS).at( 0 ).appendChild( id );
+    id.setAttribute(QStringLiteral("id"), str.setNum(ii));
+    elementsByTagName(KVTML_IDENTIFIERS).at(0).appendChild(id);
     return *this;
 }
-XMLGenerator & XMLGenerator::addLocale(const int ii) {
-    QDomElement x = this->createElement( KVTML_LOCALE );
-    QDomText loctext = this->createTextNode( ii ? lang1loc : lang0loc);
-    x.appendChild( loctext );
-    elementsByTagName(KVTML_IDENTIFIER).at( ii ).appendChild( x );
+XMLGenerator &XMLGenerator::addLocale(const int ii)
+{
+    QDomElement x = this->createElement(KVTML_LOCALE);
+    QDomText loctext = this->createTextNode(ii ? lang1loc : lang0loc);
+    x.appendChild(loctext);
+    elementsByTagName(KVTML_IDENTIFIER).at(ii).appendChild(x);
     return *this;
 }
 
@@ -259,21 +266,20 @@ XMLGenerator &XMLGenerator::addContainerEntry(int entryId)
     return *this;
 }
 
-
 void Kvtml2ReaderTest::testParseExpectedMinimalXMLAccordingToDTD()
 {
     XMLGenerator gen;
     gen.preamble().minimalInfo().minimalIds().minimalEntries();
 
     ///@todo Either Fix the DTD to agree with the code or fix the code to agree with the DTD
-    KVOCREADER_DONT_EXPECT( gen.toString(4),  KEduVocDocument::NoError, gen.myType );
+    KVOCREADER_DONT_EXPECT(gen.toString(4), KEduVocDocument::NoError, gen.myType);
 }
 void Kvtml2ReaderTest::testParseActualMinimalXML()
 {
     XMLGenerator gen;
     gen.preamble().minimalInfo().minimalIds().blankIdentifier(0).addLocale(0).minimalEntries();
 
-    KVOCREADER_EXPECT( gen.toString(4) ,  KEduVocDocument::NoError, gen.myType );
+    KVOCREADER_EXPECT(gen.toString(4), KEduVocDocument::NoError, gen.myType);
 }
 
 void Kvtml2ReaderTest::testParseMissingInformation()
@@ -281,7 +287,7 @@ void Kvtml2ReaderTest::testParseMissingInformation()
     XMLGenerator gen;
     gen.preamble().minimalIds().minimalEntries();
 
-    KVOCREADER_EXPECT( gen.toString(4) ,  KEduVocDocument::FileReaderFailed, gen.myType );
+    KVOCREADER_EXPECT(gen.toString(4), KEduVocDocument::FileReaderFailed, gen.myType);
 }
 void Kvtml2ReaderTest::testParseMissingIdentifiers()
 {
@@ -289,29 +295,29 @@ void Kvtml2ReaderTest::testParseMissingIdentifiers()
     gen.preamble().minimalInfo().minimalEntries();
 
     ///@todo Either Fix the DTD to agree with the code or fix the code to agree with the DTD
-    KVOCREADER_DONT_EXPECT( gen.toString(4) ,  KEduVocDocument::FileReaderFailed, gen.myType );
+    KVOCREADER_DONT_EXPECT(gen.toString(4), KEduVocDocument::FileReaderFailed, gen.myType);
 }
 void Kvtml2ReaderTest::testParseMissingEntries()
 {
     XMLGenerator gen;
     gen.preamble().minimalInfo().minimalIds();
 
-    KVOCREADER_EXPECT( gen.toString(4) ,  KEduVocDocument::FileReaderFailed, gen.myType );
+    KVOCREADER_EXPECT(gen.toString(4), KEduVocDocument::FileReaderFailed, gen.myType);
 }
 void Kvtml2ReaderTest::testParseMissingTitle()
 {
     XMLGenerator gen;
     gen.preamble().blankInfo().minimalIds().minimalEntries();
 
-    KVOCREADER_EXPECT( gen.toString(4) ,  KEduVocDocument::FileReaderFailed, gen.myType );
+    KVOCREADER_EXPECT(gen.toString(4), KEduVocDocument::FileReaderFailed, gen.myType);
 }
 
 void Kvtml2ReaderTest::testParseWithLocale()
 {
     XMLGenerator gen;
-    gen.preamble().blankInfo().minimalIds().minimalEntries().blankIdentifier(0).addLocale( 0 );
+    gen.preamble().blankInfo().minimalIds().minimalEntries().blankIdentifier(0).addLocale(0);
 
-    KVOCREADER_EXPECT( gen.toString(4) ,  KEduVocDocument::NoError, gen.myType );
+    KVOCREADER_EXPECT(gen.toString(4), KEduVocDocument::NoError, gen.myType);
 }
 
 void Kvtml2ReaderTest::testParseMissingLocale()
@@ -320,7 +326,7 @@ void Kvtml2ReaderTest::testParseMissingLocale()
     gen.preamble().blankInfo().minimalIds().minimalEntries().blankIdentifier(0);
 
     ///@todo Either Fix the DTD to agree with the code or fix the code to agree with the DTD
-    KVOCREADER_DONT_EXPECT( gen.toString(4) ,  KEduVocDocument::FileReaderFailed, gen.myType );
+    KVOCREADER_DONT_EXPECT(gen.toString(4), KEduVocDocument::FileReaderFailed, gen.myType);
 }
 
 void Kvtml2ReaderTest::testParseSoundUrl()
@@ -357,20 +363,17 @@ void Kvtml2ReaderTest::testParseSoundUrl_data()
     QTest::addColumn<QString>("expectedParsedUrl");
     QTest::addColumn<QString>("kvtmlFileUrl");
 
-    QTest::newRow("Relative Path")
-    << "file:sounds/bar.mp3"                // Url stored in KVTML file
-    << "file:///home/foo/sounds/bar.mp3"    // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Relative Path") << "file:sounds/bar.mp3" // Url stored in KVTML file
+                                   << "file:///home/foo/sounds/bar.mp3" // Expected parsed url
+                                   << "file:///home/foo/bar.kvtml"; // KVTML file url
 
-    QTest::newRow("Absolute Path")
-    << "file:///data/sounds/bar.mp3"        // Url stored in KVTML file
-    << "file:///data/sounds/bar.mp3"        // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Absolute Path") << "file:///data/sounds/bar.mp3" // Url stored in KVTML file
+                                   << "file:///data/sounds/bar.mp3" // Expected parsed url
+                                   << "file:///home/foo/bar.kvtml"; // KVTML file url
 
-    QTest::newRow("Remote Path")
-    << "http://example.com/sounds/bar.mp3"  // Url stored in KVTML file
-    << "http://example.com/sounds/bar.mp3"  // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Remote Path") << "http://example.com/sounds/bar.mp3" // Url stored in KVTML file
+                                 << "http://example.com/sounds/bar.mp3" // Expected parsed url
+                                 << "file:///home/foo/bar.kvtml"; // KVTML file url
 }
 
 void Kvtml2ReaderTest::testParseImageUrl()
@@ -407,27 +410,20 @@ void Kvtml2ReaderTest::testParseImageUrl_data()
     QTest::addColumn<QString>("expectedParsedUrl");
     QTest::addColumn<QString>("kvtmlFileUrl");
 
-    QTest::newRow("Relative Path")
-    << "file:images/bar.png"                // Url stored in KVTML file
-    << "file:///home/foo/images/bar.png"    // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Relative Path") << "file:images/bar.png" // Url stored in KVTML file
+                                   << "file:///home/foo/images/bar.png" // Expected parsed url
+                                   << "file:///home/foo/bar.kvtml"; // KVTML file url
 
-    QTest::newRow("Absolute Path")
-    << "file:///data/images/bar.png"        // Url stored in KVTML file
-    << "file:///data/images/bar.png"        // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Absolute Path") << "file:///data/images/bar.png" // Url stored in KVTML file
+                                   << "file:///data/images/bar.png" // Expected parsed url
+                                   << "file:///home/foo/bar.kvtml"; // KVTML file url
 
-    QTest::newRow("Remote Path")
-    << "http://example.com/images/bar.png"  // Url stored in KVTML file
-    << "http://example.com/images/bar.png"  // Expected parsed url
-    << "file:///home/foo/bar.kvtml";        // KVTML file url
+    QTest::newRow("Remote Path") << "http://example.com/images/bar.png" // Url stored in KVTML file
+                                 << "http://example.com/images/bar.png" // Expected parsed url
+                                 << "file:///home/foo/bar.kvtml"; // KVTML file url
+}
 }
 
-
-}
-
-QTEST_MAIN( Kvtml2ReaderUnitTests::Kvtml2ReaderTest )
-
-
+QTEST_MAIN(Kvtml2ReaderUnitTests::Kvtml2ReaderTest)
 
 #include "readerkvtml2test.moc"
