@@ -2,7 +2,7 @@
  * SPDX-FileCopyrightText: 2007 Jeremy Whiting <jpwhiting@kde.org>
  * SPDX-FileCopyrightText: 2007 Frederik Gladhorn <frederik.gladhorn@kdemail.net>
  * SPDX-License-Identifier: GPL-2.0-or-later
-*/
+ */
 
 #include "keduvocwordtype.h"
 
@@ -15,24 +15,26 @@ class KEduVocWordType::Private
 public:
     // bitvector of word type flags
     KEduVocWordFlags m_flags;
-    QList<KEduVocExpression*> m_expressions;
+    QList<KEduVocExpression *> m_expressions;
     // list of translations
-    QList<KEduVocTranslation*> m_translations;
+    QList<KEduVocTranslation *> m_translations;
 };
 
-KEduVocWordType::KEduVocWordType(const QString& name, KEduVocWordType *parent)
-        : KEduVocContainer(name, WordType, parent), d( new Private )
-{}
+KEduVocWordType::KEduVocWordType(const QString &name, KEduVocWordType *parent)
+    : KEduVocContainer(name, WordType, parent)
+    , d(new Private)
+{
+}
 
 KEduVocWordType::~KEduVocWordType()
 {
-    foreach(KEduVocTranslation* translation, d->m_translations) {
+    foreach (KEduVocTranslation *translation, d->m_translations) {
         translation->setWordType(nullptr);
     }
     delete d;
 }
 
-QList<KEduVocExpression*> KEduVocWordType::entries(EnumEntriesRecursive recursive)
+QList<KEduVocExpression *> KEduVocWordType::entries(EnumEntriesRecursive recursive)
 {
     if (recursive == Recursive) {
         return entriesRecursive();
@@ -49,11 +51,11 @@ int KEduVocWordType::entryCount(EnumEntriesRecursive recursive)
     return d->m_expressions.count();
 }
 
-void KEduVocWordType::addTranslation(KEduVocTranslation* translation)
+void KEduVocWordType::addTranslation(KEduVocTranslation *translation)
 {
     // add to expression - if not already there because another translation of the same word is there.
     bool found = false;
-    foreach(int i, translation->entry()->translationIndices()) {
+    foreach (int i, translation->entry()->translationIndices()) {
         if (translation->entry()->translation(i)->wordType() == this) {
             found = true;
             break;
@@ -62,13 +64,13 @@ void KEduVocWordType::addTranslation(KEduVocTranslation* translation)
     if (!found) {
         d->m_expressions.append(translation->entry());
     }
-    d->m_translations.append( translation );
+    d->m_translations.append(translation);
     invalidateChildLessonEntries();
 }
 
-void KEduVocWordType::removeTranslation(KEduVocTranslation* translation)
+void KEduVocWordType::removeTranslation(KEduVocTranslation *translation)
 {
-    d->m_translations.removeAt( d->m_translations.indexOf(translation) );
+    d->m_translations.removeAt(d->m_translations.indexOf(translation));
 
     // no lesson found - this entry is being deleted. remove all its siblings.
     if (!translation->entry()->lesson()) {
@@ -80,8 +82,9 @@ void KEduVocWordType::removeTranslation(KEduVocTranslation* translation)
 
     // remove from cache if none of the translations use this word type (other than the one we are removing that should not be taken into account)
     bool found = false;
-    foreach(int i, translation->entry()->translationIndices()) {
-        if (translation->entry()->translation(i)->wordType() && translation->entry()->translation(i)->wordType() == this && translation->entry()->translation(i) != translation) {
+    foreach (int i, translation->entry()->translationIndices()) {
+        if (translation->entry()->translation(i)->wordType() && translation->entry()->translation(i)->wordType() == this
+            && translation->entry()->translation(i) != translation) {
             found = true;
             break;
         }
@@ -93,13 +96,12 @@ void KEduVocWordType::removeTranslation(KEduVocTranslation* translation)
     invalidateChildLessonEntries();
 }
 
-KEduVocTranslation * KEduVocWordType::translation(int row)
+KEduVocTranslation *KEduVocWordType::translation(int row)
 {
-
     return d->m_translations.value(row);
 }
 
-KEduVocExpression * KEduVocWordType::entry(int row, EnumEntriesRecursive recursive)
+KEduVocExpression *KEduVocWordType::entry(int row, EnumEntriesRecursive recursive)
 {
     if (recursive == Recursive) {
         return entriesRecursive().value(row);
@@ -117,17 +119,16 @@ void KEduVocWordType::setWordType(KEduVocWordFlags flags)
     d->m_flags = flags;
 }
 
-KEduVocWordType* KEduVocWordType::childOfType(KEduVocWordFlags flags)
+KEduVocWordType *KEduVocWordType::childOfType(KEduVocWordFlags flags)
 {
-    if(d->m_flags == flags) {
+    if (d->m_flags == flags) {
         return this;
     }
-    foreach(KEduVocContainer* child, childContainers()) {
-        KEduVocWordType* result = static_cast<KEduVocWordType*>(child)->childOfType(flags);
-        if(result) {
+    foreach (KEduVocContainer *child, childContainers()) {
+        KEduVocWordType *result = static_cast<KEduVocWordType *>(child)->childOfType(flags);
+        if (result) {
             return result;
         }
     }
     return nullptr;
 }
-
